@@ -1,10 +1,12 @@
 use strict;
 use warnings;
 
-package namespace::autoclean; # git description: 0.23-2-g474266b
+package namespace::autoclean; # git description: 0.24-9-g36e6f68
 # ABSTRACT: Keep imports out of your namespace
 # KEYWORDS: namespaces clean dirty imports exports subroutines methods development
-$namespace::autoclean::VERSION = '0.24';
+
+our $VERSION = '0.25';
+
 use B::Hooks::EndOfScope 0.12;
 use List::Util qw( first );
 use namespace::clean 0.20;
@@ -199,6 +201,7 @@ sub _method_check {
             my $code_stash = Sub::Identify::stash_name($coderef);
             return 1 if $code_stash eq $package;
             return 1 if $code_stash eq 'constant';
+            # TODO: consider if we really need this eval
             return 1 if $does && eval { $package->$does($code_stash) };
             return 0;
         };
@@ -219,7 +222,7 @@ namespace::autoclean - Keep imports out of your namespace
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 SYNOPSIS
 
@@ -373,13 +376,6 @@ L<Dist::Zilla::Plugin::Test::CleanNamespaces>
 
 Florian Ragwitz <rafl@debian.org>
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2009 by Florian Ragwitz.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
 =for stopwords Karen Etheridge Graham Knop Dave Rolsky Kent Fredric Tomas Doran Shawn M Moore Felix Ostmann Chris Prather Andrew Rodland
@@ -424,4 +420,11 @@ Andrew Rodland <andrew@hbslabs.com>
 
 =back
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2009 by Florian Ragwitz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
